Deployment
==========

Build Symphytum:
----------------

1. Check and update translation files if needed
2. Check `DefinitionHolder`
3. Set dropbox app secret in `DropboxSyncDriver::initSecrets()`
4. Check authors description in about dialog, see AUTHORS file
5. Check and update `CHANGELOG` file
6. Create archive of last commit:
```
   git archive -o symphytum-1.0-src.tar.gz HEAD
```
7. Uncompress and open project with release config
8. Compile

Prepare Dropbox SDK:
----------------
1. Edit `components/sync_framework/scripts/dropbox_client.py`
   and set correct app key
2. Download latest Dropbox python SDK:
   https://www.dropbox.com/developers/
4. Go to `dropbox` folder in the sdk folder
5. Copy `dropbox_client.py` and the `dropbox` folder to somewhere for later use

Windows:
----------------
1. Prepare dropbox client (windows exe) as described in "pyinstaller dropbox howto" or reuse from previous deployment (setup.exe)
2. Download MEGAcmd installer for windows from https://mega.nz/cmd, which is used by the installer (.iss) script
3. Open and compile `symphytum.iss` after review
4. The missing .DLL files can be copied from the Qt install or use `windeployqt`

Windows Portable:
----------------
1. Follow similar steps as above
2. Enable `DefinitionHolder::WIN_PORTABLE` before compiling to use local and portable storage directories
3. Instead of running installer, just create a zip

macOS:
----------------
1. Use `qmake -spec macx-clang Symphytum.pro` to generate Makefile
2. Move py files to app boundle in the sync subfolder where the binary is (unarchive macOS python deploy.tar.gz first)
3. Use `macdeployqt`
4. Add the following to the `Info.plist` file inside the app bundle to force the light theme on mojave (10.14). This is required until Qt implements proper support for dark theme.
```
    <key>NSRequiresAquaSystemAppearance</key>
    <string>True</string>
```
5. Add or modify the following entries to the Info.plist file.
```
    <key>Bundle identifier</key>
    <string>com.giowisys.Symphytum</string>
    <key>Bundle version</key>
    <string>2.4</string>
    <key>Bundle versions string, short</key>
    <string>2.4</string>
```
6. Create a DMG follow this: http://mac101.net/content/how-to/how-to-create-dmg-art-for-fancy-application-installations/
   (alt link: https://web.archive.org/web/20150423212042/http://mac101.net/content/how-to/how-to-create-dmg-art-for-fancy-application-installations/)

Ubuntu:
----------------
1. Copy `deb` dir from `installers` dir
2. Update `DEBIAN/control` as needed
3. Copy executable to `usr/bin`
4. Copy `dropbox_client.py` and `dropbox` to `usr/share/symphytum/sync` (unarchive dropbox.tar.gz first)
5. Create deb package
```
   sudo chown root:root -R deb/
   sudo chmod -R 0755 deb/
   dpkg -b deb/ symphytum-1.0-x86_64.deb
```

Arch Linux:
----------------
1. Adjust `PKGBUILD` script from the `installers` directory
2. copy source tarball to current build directory
3. run `updpkgsums` to update checksums for source tarball
4. `makepkg --printsrcinfo > .SRCINFO`
5. run `makepkg -i` to build pacman package and to install it

AppImage:
----------------
```
-> Create or reuse from a previous AppImage (see --appimage-extract command) the pyinstaller package for linux
   on for example Ubuntu 16.04 LTS:
   sudo apt install python-pip
   pip install pyinstaller
   pip install dropbox
-> Copy the dropbox_client.py file to a work directory
-> Build pyinstaller package:
   pyinstaller dropbox_client.py
-> Copy the dist/dropbox_client directory for later use.
-> Use Ubuntu 16.04 LTS for the AppImage creation
-> Install missing deps:
   sudo apt install build-essential mesa-common-dev libglu1-mesa-dev libmysqlclient20 libpq5 libodbc1 libsybdb5
-> Download Qt installer from qt.io/download
-> Set APPIMAGE_LINUX to true in DefinitionHolder and then compile project in release mode
-> Download linuxdeployqt from https://github.com/probonopd/linuxdeployqt
-> Download AppImageKit from https://github.com/AppImage/AppImageKit:
   wget "https://github.com/AppImage/AppImageKit/releases/download/continuous/appimagetool-x86_64.AppImage"
   chmod a+x appimagetool-x86_64.AppImage
-> Create myappimg folder on desktop and place files from stuff/deb/ here:
   copy the compiled symphytum binary to myappimg/usr/bin
   copy the whole usr/share folder from stuff/deb to myappimg/usr/share
   remove dropbox folder/archive and dropbox_client.py from myappimg/usr/share/symphytum/sync/
   remove DEBIAN folder from myappimg folder
-> Create the AppDir with:
   ./linuxdeployqt-continuous-x86_64.AppImage /home/user/Desktop/myappimg/usr/share/applications/symphytum.desktop  -bundle-non-qt-libs -no-translations -qmake=/home/user/Qt/5.9.2/gcc_64/bin/qmake
-> If you get an error about missing sql libs, try https://github.com/probonopd/linuxdeployqt/issues/70#issuecomment-293471028
-> Integrate the pyinstaller package from above (after step above to avoid missing lib errors, pyinstaller is already self contained):
   move the previously created pyinstaller package (dropbox_client folder from above) to myappimg/usr/share/symphytum/sync/
   now the dropbox driver executable should be at myappimg/usr/share/symphytum/sync/dropbox_client/dropbox_client
-> This is no longer needed as of Qt 5.11.3: Patch the AppDir to fix an OpenSSL currently affecting Qt's SDK, see https://github.com/Subsurface-divelog/subsurface/issues/779
   sed -i -e 's|1.0.1e|1.0.0\x00|g' /home/user/Desktop/myappimg/usr/lib/libQt5Network.so.5
   for Qt 5.10.1 use: sed -i -e 's|1.0.2k|1.0.0\x00|g' /home/user/Desktop/myappimg/usr/lib/libQt5Network.so.5
   for future Qt versions, try to detect changes with: strings libQt5Network.so.5 | grep '1\.0\'.
-> Create the final AppImage with:
   ./appimagetool-x86_64.AppImage /home/user/Desktop/myappimg
```

Snap:
----------------
1. Use Ubuntu 18.04 or the latest supported LTS by snapcraft
2. Run snapcraft in the `stuff/installers/snap` directory after reviewing the yaml file
3. Upload new snap to snap store
